#ifndef _LINUX_VZ_FS_H
#define _LINUX_VZ_FS_H

#include <linux/types.h>
#include <linux/ioctl.h>

#define VEFS_DIRLINK_NAME "._vzlnk_."
#define VZFS_SUPER_MAGIC 0x565a4653 /* VZFS */

#ifndef __user
#define __user
#endif

struct vzfs_link_tmpl
{
	char		__user *name;
	char		__user *tmpl_path;
	__u32		mode;
};

struct vzfs_ioc_track
{
	__u32		__user flags;
	__u32		__user fd;
	__u32		__user reserved[6];
};
#define VZFS_IOC_TRACK_PRIVATE_FL	0x1

#define VZFSCTLTYPE 0xAA
#define VZCTL_VZFS_TRACKON	_IOW(VZFSCTLTYPE, 0, int)
#define VZCTL_VZFS_TRACKOFF	_IOW(VZFSCTLTYPE, 1, int)
#define VEFS_SET_MARK		_IO(VZFSCTLTYPE, 2)
#define VEFS_CLEAR_MARK		_IO(VZFSCTLTYPE, 3)
#define VEFS_CHECK_MARK		_IO(VZFSCTLTYPE, 4)
#define VEFS_REPLACE_MARKED	_IOW(VZFSCTLTYPE, 5, char *)	/* *$* */
#define VEFS_LINK_TEMPLATE	_IOW(VZFSCTLTYPE, 6, struct vzfs_link_tmpl *)
#define VEFS_CACHE_MARKED	_IOW(VZFSCTLTYPE, 7, char *)	/* *$* */
#define VEFS_UNCACHE		_IO(VZFSCTLTYPE, 8)
#define VZCTL_VZFS_TRACKON2	_IOW(VZFSCTLTYPE, 9, struct vzfs_ioc_track)
/*
 * *$* -- these ioctls are bad designed as it's number depends
 * on sizeof(char *), so they need compat :/	dev@
 */

#define	VEFS_IOC_GETFLAGS	_IOR('f', 1, long)
#define	VEFS_IOC_SETFLAGS	_IOW('f', 2, long)

#define	VEFS_IOC32_GETFLAGS	_IOR('f', 1, int)
#define	VEFS_IOC32_SETFLAGS	_IOW('f', 2, int)

#ifdef __KERNEL__

struct vzsnap_struct;
extern int vefs_snap_init(struct dentry * vdentry, struct vfsmount * mnt,
			  struct vzsnap_struct *vzs);
extern int vefs_snap_stop(struct vzsnap_struct * vzs);


#ifdef CONFIG_COMPAT
#include <linux/compat.h>

struct compat_vzfs_link_tmpl
{
	compat_uptr_t	name;
	compat_uptr_t	tmpl_path;
	u32		mode;
};

#define VEFS_REPLACE_MARKED_COMPAT	_IOW(VZFSCTLTYPE, 5, compat_uptr_t)	/* *$* */
#define VEFS_LINK_TEMPLATE_COMPAT	_IOW(VZFSCTLTYPE, 6, compat_uptr_t)	/* *$* */
#define VEFS_CACHE_MARKED_COMPAT	_IOW(VZFSCTLTYPE, 7, compat_uptr_t)	/* *$* */
#endif
#endif
#endif
