/* Index file is a regular file with name VEFS_DIRLINK_NAME.
 * Note that magic directory link has the same name, we distinguish
 * them by file type: S_ISLNK means magic link, S_ISREG means dirindex.
 */

/* Header with meta information and stat of template directory,
 * which is not cached at private directory inode (nlink)
 */

struct vefs_dir_header
{
	__u32	version;	/* Must be: */
#define VEFS_DIRINDEX_VERSION	0x402de119
	__u32	start;		/* Offset to the first dir entry */
	__u32	nlink;		/* Number of subdirectories + 2 */
	__u32	hash_prime;	/* Number of buckets in hash table */
	__u8	checksum[4];	/* for fsck, the first 4 bytes of MD5 */
	__u32	hash_table[0];	/* Place for hash table */
};

/* Then optional hash table of hash_prime u32 entries with offsets to start
 * of hash chains. hash_prime == 1 means plain list.
 *
 * Yes, it uses plain table lookup with linear bucket chains.
 * I do not have any experience with on disk databases, but
 * plain logic tells me that the fact that the whole lookup
 * requires only 1-2 pages for all existing directories
 * justifies the choice. Tree would take log(N), it is 4
 * for /usr/share/man/man3.
 */

struct vefs_dir_entry
{
	__u8	dtype;		/* readdir() DT_* */
	__u8	marker;		/* marks end of hash chain, end of file... */
#define VEFS_DIRINDEX_EOH	1
#define VEFS_DIRINDEX_EOF	2
	__u16	namelen;	/* Length of .name */
#define VEFS_DIRINDEX_MAXNAME	256
	__u32	reclen;		/* It is offset to the next entry */
#define VEFS_DIRINDEX_MAXREC	4096
	__u32	inode;		/* i_ino in template */
	__u32	link_offset;	/* It is offset to the content, it can
				 * be everywhere in the file */

#if 0
	/* Looks cool, but useless and increases size of dirindex twice. */
	__u32	mode;
	__u32	uid;
	__u32	gid;
	__u32	nlink;
	__u32	size[2];
	__u32	atime[2];
	__u32	mtime[2];
	__u32	ctime[2];
#endif

	__u8	name[0];	/* Entry name, zero terminated,
				 * zero padded to u32 */
};

/* Link content is embedded in holes between namelen...reclen.
 * I expect it is good for locality, maybe, not.
 *
 * If dtype is DT_LNK, the link is real symlink, DT_DIR it is 0,
 * for DT_REG it is magic without file name itself.
 */
struct vefs_link_entry
{
	__u32	linklen;	/* Length of .link */
	__u8	link[0];	/* Link content, zero terminated,
				 * zero padded to u32 */
};

/* String must be u32 aligned. It is in dcache.
 * By some strange reason it gives less variance than R5 on redhat-as4-x86.
 */
static inline __u32 vefs_hash_fn(const char *p, int len, __u32 prime)
{
	__u32 a = 0;

	while (len >= 4) {
		a = (a << 4) ^ (a >> 4) ^ *(__u32*)p;
		p += 4;
		len -= 4;
	}
	while (len > 0) {
		a = (a << 4) ^ (a >> 4) ^ *p;
		p++;
		len--;
	}
	return a % prime;
}
